@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 from xml.etree import ElementTree as ET
+import os
 
 class LibMarkdown(object):
     def __init__(self):
@@ -172,6 +173,14 @@ class LibMarkdown(object):
             data += str(i) + "|"
         data = data + "\n"
         return data
+
+    def tex_create_body_line(self, argv, path):
+        link = os.path.join(path, argv[0].split("||")[0] + '.md')
+        data = "|[" + argv[0].replace("||","_") + "](" + link + ")|"
+        for i in argv[1:]:
+            data += str(i) + "|"
+        data = data + "\n"
+        return data
     
     def md_register_name(self, name):
         data = "### " + name + "\n"
