@@ -14,7 +14,7 @@ except ImportError:
     import libsvg
     import libmd
 
-__version__ = 'v1.1.7'
+__version__ = 'v1.1.9'
 
 class TranslateJson(object):
     def __init__(self, js_file, link_path, dir_type, output_md, output_gitbook):
@@ -39,6 +39,8 @@ class TranslateJson(object):
         self.reg_data = ''
         self.path_addr_dict = {}
         self.max_len = ''
+        self.reg_rst = '寄存器详细说明\n==============\n\n.. toctree::\n'
+        self.reg_rst += '   :caption: Contents:\n\n'
 
     def get_dpath(self, in_dict, pre_path = ''):
         path_list = []
@@ -404,6 +406,7 @@ class TranslateJson(object):
             os.system("mv " + svg_name + " " + self.gitbookpath)
             register_data += '\n<br>\n'
             file_path = os.path.join(self.gitbookpath, name + '.md')
+            self.reg_rst += '   ' + name + '.md\n'
             with open(file_path, 'w') as fd:
                 fd.write(register_data)
             self.reg_data += '{% include "./' + name +  '.md" %}\n'
@@ -517,6 +520,8 @@ class TranslateJson(object):
                         fc.write("## " + file_msg + "寄存器列表\n\n" + self.all_reg_tex_data)
                     with open(os.path.join(self.gitbookpath, 'detail.md'), 'w') as fc:
                         fc.write(self.reg_data)
+                    with open(os.path.join(self.gitbookpath, 'detail.rst'), 'w') as fc:
+                        fc.write(self.reg_rst)
                 self.check_file('README.md')
                 self.check_file('SUMMARY.md')
                 print("\n\tcreate " + self.gitbookpath +" success") 
@@ -527,7 +532,7 @@ class TranslateJson(object):
                 os.system("mkdir -p " + self.markdownpath)
             md_file = os.path.join(self.markdownpath, file_msg + ".md")
             for i in self.js_dpath:
-                selfgpath_addr_dict[i] = self.get_addr(i)
+                self.path_addr_dict[i] = self.get_addr(i)
             self.max_len = len(self.path_addr_dict[self.js_dpath[-1]][2:])
             for i in self.js_dpath:
                 self.create_md3(i, lm)
